import { StructuredError } from "./error.js";
import { z } from 'zod';
import { HttpMethodSchema } from "./fetch.js";
export const ServiceExceptionPayloadSchema = z
    .object({
    statusCode: z.number().describe('HTTP status code returned by the service.'),
    method: HttpMethodSchema.describe('HTTP method used in the request.'),
    url: z.string().describe('URL of the failed request.'),
    sessionId: z
        .string()
        .optional()
        .nullable()
        .describe('Session ID associated with the request, if any.'),
})
    .describe('Payload for service exception errors.');
export const ServiceException = StructuredError('ServiceException')();
//# sourceMappingURL=exception.js.map